@@ -14,17 +14,20 @@ class LoggingInterceptor(BaseInterceptor):
     def _callHandlers(self, callHandlers, logger, record):
         with self.log_exceptions():
             if not record.name.startswith('pythonagent') and self.bt:
-                print("error message as ",record.getMessage())
+                self.agent.logger.info("error message as {}".format(record.getMessage()))
                 self.add_logged_error(record)
-                
-        #print("Befor call handers method call")
 
-        context = self.agent.get_transaction_context()
-        recordReqIdmsg = f" [ RequestId : {context.aws_request_id} ] "+record.msg
-        record.msg = recordReqIdmsg
+        try:
+            if type(record.msg) != str:
+                record.msg = str(record.msg)
+
+            context = self.agent.get_transaction_context()
+            recordReqIdmsg = f" [ RequestId : {context.aws_request_id} ] " + record.msg
+            record.msg = recordReqIdmsg
+        except Exception as e:
+            print(e)
 
         callHandlers(logger, record)
-        #print("After callHandlers methods call")
 
     def add_logged_error(self, record):
         """Add an error to the BT if the log record should trigger an error.
